part of 'floative_factory.dart';

class _FloativeFactoryImpl implements FloativeFactory {
  static final _registeredInstances = <Type, _Factory>{};

  @override
  T get<T>({Map<String, dynamic> args = const <String, dynamic>{}}) {
    if (_FactoryHelper.isRegistered<T>(_registeredInstances)) {
      var result = _registeredInstances[T];
      return result.getInstance(args: args);
    } else {
      return null;
    }
  }

  @override
  void register<T>(InstanceFunction<T> instanceFunction,
      {bool overrideInstance = false,
      bool isLazy = false,
      Map<String, dynamic> args}) {
    if (_FactoryHelper.isNotRegistered<T>(_registeredInstances)) {
      _registeredInstances.putIfAbsent(
          T,
          () => _Factory<T>(
              instanceFunction: instanceFunction,
              factoryType:
                  isLazy ? _FactoryType.lazy : _FactoryType.singleton));
    } else {
      if (overrideInstance) {
        _registeredInstances[T] = _Factory<T>(
            instanceFunction: instanceFunction,
            factoryType: isLazy ? _FactoryType.lazy : _FactoryType.singleton);
      }
    }
  }

  @override
  void registerFactory<T>(InstanceFunction<T> instanceFunction) {
    if (_FactoryHelper.isNotRegistered<T>(_registeredInstances)) {
      _registeredInstances.putIfAbsent(
          T,
          () => _Factory<T>(
              instanceFunction: instanceFunction,
              factoryType: _FactoryType.factory));
    }
  }

  @override
  void dispose<T>() {
    if (_FactoryHelper.isRegistered<T>(_registeredInstances)) {
      _registeredInstances.remove(T);
    }
  }

  @override
  void reset() {
    _registeredInstances.clear();
  }
}
