import 'package:flutter/material.dart';

import '../../floative_flutter.dart';

class TextIntl extends StatelessWidget {
  final String textKey;
  final TextStyle style;
  final StrutStyle strutStyle;
  final TextAlign textAlign;
  final TextDirection textDirection;
  final Locale locale;
  final bool softWrap;
  final TextOverflow overflow;
  final double textScaleFactor;
  final int maxLines;
  final String semanticsLabel;
  final TextWidthBasis textWidthBasis;
  final TextHeightBehavior textHeightBehavior;

  TextIntl(
    this.textKey, {
    Key key,
    this.style,
    this.strutStyle,
    this.textAlign,
    this.textDirection,
    this.locale,
    this.softWrap,
    this.overflow,
    this.textScaleFactor,
    this.maxLines,
    this.semanticsLabel,
    this.textWidthBasis,
    this.textHeightBehavior,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Text(_translateKey(context),
        style: style,
        strutStyle: strutStyle,
        textAlign: textAlign,
        textDirection: textDirection,
        locale: locale,
        softWrap: softWrap,
        overflow: overflow,
        textScaleFactor: textScaleFactor,
        maxLines: maxLines,
        semanticsLabel: semanticsLabel,
        textWidthBasis: textWidthBasis,
        textHeightBehavior: textHeightBehavior);
  }

  String _translateKey(BuildContext context) {
    try {
      var internationalization = Floative.I.internationalization?.of(context);

      if (internationalization == null) {
        throw FloativeException(""
            "FloativeIntl was not set correctly. [is null] "
            "before using the translation feature of Floative, "
            "please, read the intl doc. Open an issue if you think"
            "you have used it correctly."
            "");
      }

      return internationalization.translate(textKey) ?? "";
    } catch (e) {
      if (Floative.I.enableFloativeLogs &&
          Floative.I.currentFlavor == Flavor.development) {
        Logger.error(
            where: "TextItl",
            function: "_translateKey",
            exception: e,
            parameters: [textKey]);
      }
      return "";
    }
  }
}
