import 'dart:async';
import 'dart:collection';

import 'package:flutter/cupertino.dart';

import '../reactive_base.dart';

@immutable
class NewElementOnListEvent {}

class ReactiveList<E> extends ListBase<E> implements ReactiveBase {
  final List<E> l = [];

  final StreamController _controller = StreamController.broadcast();

  ReactiveList();

  factory ReactiveList.fromList(List<E> elementList) {
    final list = ReactiveList<E>();
    list.addAll(elementList);
    return list;
  }

  set length(int newLength) {
    l.length = newLength;
  }

  int get length => l.length;
  E operator [](int index) => l[index];
  void operator []=(int index, E value) {
    l[index] = value;
    _controller.sink.add(NewElementOnListEvent);
  }

  @override
  void add(E element) {
    _controller.sink.add(NewElementOnListEvent);
    super.add(element);
  }

  @override
  Stream get onChange => _controller.stream;

  @override
  void dispose() {
    _controller.close();
  }
}
