import 'dart:async';
import 'dart:collection';

import 'package:flutter/cupertino.dart';

import '../../core/annotations/floative_annotations.dart';
import '../reactive_base.dart';

@immutable
class ClearMapEvent {}

@immutable
class NewValueInMapEvent {}

@AlphaFeature()
class ReactiveMap<K, V> extends MapBase<K, V> implements ReactiveBase {
  final Map<K, V> _map = <K, V>{};

  final _streamController = StreamController.broadcast();

  @override
  operator [](Object key) => _map[key];

  @override
  void operator []=(key, value) {
    _map[key] = value;
    _streamController.sink.add(NewValueInMapEvent);
  }

  @override
  void clear() {
    _map.clear();
    _streamController.sink.add(ClearMapEvent);
  }

  @override
  V putIfAbsent(K key, V Function() ifAbsent) {
    _streamController.sink.add(NewValueInMapEvent);
    return super.putIfAbsent(key, ifAbsent);
  }

  @override
  Iterable<K> get keys => _map.keys;

  @override
  // ignore: type_annotate_public_apis
  remove(Object key) {
    _map.remove(key);
    _streamController.sink.add(NewValueInMapEvent);
  }

  @override
  void dispose() {
    _streamController.close();
  }

  @override
  Stream get onChange => _streamController.stream;
}
