import 'package:flutter/material.dart';

import '../core/flavor/flavor.dart';
import '../core/floative_base/floative.dart';
import '../ship/ship.dart';

class FloativeApp extends StatelessWidget {
  final Widget home;
  final Flavor flavor;
  final bool showFloativeLogs;
  final GlobalKey<NavigatorState> navigatorKey;
  final List<NavigatorObserver> navigatorObservers;
  final TransitionBuilder builder;
  final String title;
  final GenerateAppTitle onGenerateTitle;
  final ThemeData theme;
  final ThemeData darkTheme;
  final Color color;
  final ThemeMode themeMode;
  final Locale locale;
  final Iterable<LocalizationsDelegate<dynamic>> localizationsDelegates;
  final LocaleListResolutionCallback localeListResolutionCallback;
  final LocaleResolutionCallback localeResolutionCallback;
  final Iterable<Locale> supportedLocales;
  final bool debugShowMaterialGrid;
  final Map<LogicalKeySet, Intent> shortcuts;
  final bool showPerformanceOverlay;
  final bool checkerboardRasterCacheImages;
  final bool checkerboardOffscreenLayers;
  final bool showSemanticsDebugger;
  final bool debugShowCheckedModeBanner;

  FloativeApp({
    Key key,
    @required this.home,
    this.title = "",
    this.navigatorKey,
    this.flavor = Flavor.development,
    this.showFloativeLogs,
    this.navigatorObservers = const <NavigatorObserver>[],
    this.builder,
    this.onGenerateTitle,
    this.theme,
    this.darkTheme,
    this.themeMode = ThemeMode.system,
    this.color,
    this.locale,
    this.localizationsDelegates,
    this.localeListResolutionCallback,
    this.localeResolutionCallback,
    this.supportedLocales = const <Locale>[Locale('en', 'US')],
    this.debugShowMaterialGrid = false,
    this.showPerformanceOverlay = false,
    this.checkerboardRasterCacheImages = false,
    this.checkerboardOffscreenLayers = false,
    this.showSemanticsDebugger = false,
    this.debugShowCheckedModeBanner = false,
    this.shortcuts,
  }) : super(key: key) {
    Floative.I.currentFlavor = flavor;
    Floative.I.enableFloativeLogs = showFloativeLogs;
    Ship.I.init();
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        debugShowCheckedModeBanner: debugShowCheckedModeBanner,
        showPerformanceOverlay: showPerformanceOverlay,
        showSemanticsDebugger: showSemanticsDebugger,
        checkerboardRasterCacheImages: checkerboardRasterCacheImages,
        checkerboardOffscreenLayers: checkerboardOffscreenLayers,
        navigatorKey: navigatorKey ?? Ship.I.navigationKey,
        navigatorObservers: [Ship.I.navigationObserver, ...navigatorObservers],
        home: home,
        builder: builder,
        title: title ?? "",
        onGenerateTitle: onGenerateTitle,
        theme: theme,
        darkTheme: darkTheme,
        themeMode: themeMode,
        color: color,
        locale: locale,
        localizationsDelegates: localizationsDelegates,
        localeListResolutionCallback: localeListResolutionCallback,
        localeResolutionCallback: localeResolutionCallback,
        supportedLocales: supportedLocales,
        debugShowMaterialGrid: debugShowMaterialGrid,
        shortcuts: shortcuts);
  }
}
